import type { Logger } from '../logger';
import type { InboundTransporter } from '../transport/InboundTransporter';
import type { OutboundTransporter } from '../transport/OutboundTransporter';
import type { InitConfig } from '../types';
import type { Wallet } from '../wallet/Wallet';
import type { AgentDependencies } from './AgentDependencies';
import type { TransportSession } from './TransportService';
import type { Subscription } from 'rxjs';
import type { DependencyContainer } from 'tsyringe';
import { BasicMessagesModule } from '../modules/basic-messages/BasicMessagesModule';
import { ConnectionsModule } from '../modules/connections/ConnectionsModule';
import { CredentialsModule } from '../modules/credentials/CredentialsModule';
import { DiscoverFeaturesModule } from '../modules/discover-features';
import { LedgerModule } from '../modules/ledger/LedgerModule';
import { ProofsModule } from '../modules/proofs/ProofsModule';
import { MediatorModule } from '../modules/routing/MediatorModule';
import { RecipientModule } from '../modules/routing/RecipientModule';
import { AgentConfig } from './AgentConfig';
import { EventEmitter } from './EventEmitter';
import { MessageReceiver } from './MessageReceiver';
import { MessageSender } from './MessageSender';
import { TransportService } from './TransportService';
export declare class Agent {
    protected agentConfig: AgentConfig;
    protected logger: Logger;
    protected container: DependencyContainer;
    protected eventEmitter: EventEmitter;
    protected wallet: Wallet;
    protected messageReceiver: MessageReceiver;
    protected transportService: TransportService;
    protected messageSender: MessageSender;
    inboundTransporter?: InboundTransporter;
    private _isInitialized;
    messageSubscription: Subscription;
    readonly connections: ConnectionsModule;
    readonly proofs: ProofsModule;
    readonly basicMessages: BasicMessagesModule;
    readonly ledger: LedgerModule;
    readonly credentials: CredentialsModule;
    readonly mediationRecipient: RecipientModule;
    readonly mediator: MediatorModule;
    readonly discovery: DiscoverFeaturesModule;
    constructor(initialConfig: InitConfig, dependencies: AgentDependencies);
    setInboundTransporter(inboundTransporter: InboundTransporter): void;
    registerOutboundTransporter(outboundTransporter: OutboundTransporter): void;
    get outboundTransporters(): OutboundTransporter[];
    get events(): EventEmitter;
    get isInitialized(): boolean;
    initialize(): Promise<void>;
    shutdown({ deleteWallet }?: {
        deleteWallet?: boolean;
    }): Promise<void>;
    get publicDid(): import("../wallet/Wallet").DidInfo | undefined;
    receiveMessage(inboundPackedMessage: unknown, session?: TransportSession): Promise<void>;
    get injectionContainer(): DependencyContainer;
}
