"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InboundMessageContext = void 0;
const error_1 = require("../../error");
class InboundMessageContext {
    constructor(message, context = {}) {
        this.message = message;
        this.recipientVerkey = context.recipientVerkey;
        this.senderVerkey = context.senderVerkey;
        this.connection = context.connection;
    }
    /**
     * Assert the inbound message has a ready connection associated with it.
     *
     * @throws {AriesFrameworkError} if there is no connection or the connection is not ready
     */
    assertReadyConnection() {
        if (!this.connection) {
            throw new error_1.AriesFrameworkError(`No connection associated with incoming message ${this.message.type}`);
        }
        // Make sure connection is ready
        this.connection.assertReady();
        return this.connection;
    }
}
exports.InboundMessageContext = InboundMessageContext;
//# sourceMappingURL=InboundMessageContext.js.map