"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConnectionResponseHandler = void 0;
const helpers_1 = require("../../../agent/helpers");
const error_1 = require("../../../error");
const messages_1 = require("../messages");
class ConnectionResponseHandler {
    constructor(connectionService, agentConfig) {
        this.supportedMessages = [messages_1.ConnectionResponseMessage];
        this.connectionService = connectionService;
        this.agentConfig = agentConfig;
    }
    async handle(messageContext) {
        var _a, _b;
        if (!messageContext.connection) {
            throw new error_1.AriesFrameworkError(`Connection for verkey ${messageContext.recipientVerkey} not found!`);
        }
        await this.connectionService.processResponse(messageContext);
        // TODO: should we only send ping message in case of autoAcceptConnection or always?
        // In AATH we have a separate step to send the ping. So for now we'll only do it
        // if auto accept is enable
        if ((_b = (_a = messageContext.connection) === null || _a === void 0 ? void 0 : _a.autoAcceptConnection) !== null && _b !== void 0 ? _b : this.agentConfig.autoAcceptConnections) {
            const { message } = await this.connectionService.createTrustPing(messageContext.connection.id);
            return helpers_1.createOutboundMessage(messageContext.connection, message);
        }
    }
}
exports.ConnectionResponseHandler = ConnectionResponseHandler;
//# sourceMappingURL=ConnectionResponseHandler.js.map