"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordTransformer = void 0;
const class_transformer_1 = require("class-transformer");
const JsonTransformer_1 = require("./JsonTransformer");
/**
 * Decorator that transforms json to and from corresponding record.
 *
 * @example
 * class Example {
 *   RecordTransformer(Service)
 *   private services: Record<string, Service>;
 * }
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function RecordTransformer(Class) {
    return class_transformer_1.Transform(({ value, type }) => {
        switch (type) {
            case class_transformer_1.TransformationType.CLASS_TO_PLAIN:
                return Object.entries(value).reduce((accumulator, [key, attribute]) => (Object.assign(Object.assign({}, accumulator), { [key]: JsonTransformer_1.JsonTransformer.toJSON(attribute) })), {});
            case class_transformer_1.TransformationType.PLAIN_TO_CLASS:
                return Object.entries(value).reduce((accumulator, [key, attribute]) => (Object.assign(Object.assign({}, accumulator), { [key]: JsonTransformer_1.JsonTransformer.fromJSON(attribute, Class) })), {});
            default:
                return value;
        }
    });
}
exports.RecordTransformer = RecordTransformer;
//# sourceMappingURL=transformers.js.map